.. -- Dependencies ------------------------------

.. |astropy| replace:: `astropy`
.. _astropy: http://www.astropy.org/

.. |dateparser| replace:: `dateparser`
.. _dateparser: https://dateparser.readthedocs.io

.. |dateutil| replace:: `dateutil`
.. _dateutil: https://dateutil.readthedocs.io

.. |dqsegdb2| replace:: `dqsegdb2`
.. _dqsegdb2: https://dqsegdb2.readthedocs.io

.. |gwdatafind| replace:: `gwdatafind`
.. _gwdatafind: https://gwdatafind.readthedocs.io

.. |gwosc-mod| replace:: `gwosc`
.. _gwosc-mod: https://gwosc.readthedocs.io

.. |h5py| replace:: `h5py`
.. _h5py: http://docs.h5py.org/en/latest/

.. |igwn-segments| replace:: `igwn-segments`
.. _igwn-segments: https://igwn-segments.readthedocs.io/

.. |ligotimegps| replace:: `ligotimegps`
.. _ligotimegps: https://github.com/gwpy/ligotimegps/

.. |matplotlib| replace:: `matplotlib`
.. _matplotlib: https://matplotlib.org/

.. |numpy| replace:: `numpy`
.. _numpy: http://numpy.org/

.. |scipy| replace:: `scipy`
.. _scipy: http://www.scipy.org/

.. |six| replace:: `six`
.. _six: https://six.readthedocs.io/

.. |tqdm| replace:: `tqdm`
.. _tqdm: https://github.com/tqdm/tqdm

.. -- Extra software ----------------------------

.. |cWB| replace:: cWB
.. _cWB: https://gwburst.gitlab.io/documentation/latest/html/

.. |cWBl| replace:: coherent WaveBurst (cWB)
.. _cWBl: https://gwburst.gitlab.io/documentation/latest/html/

.. |framel| replace:: `framel`
.. _framel: http://lappweb.in2p3.fr/virgo/FrameL/

.. |LDAStools.frameCPP| replace:: `LDAStools.frameCPP`
.. _LDAStools.frameCPP: https://computing.docs.ligo.org/ldastools/LDAS_Tools/ldas-tools-framecpp/

.. |lal| replace:: `lal`
.. _lal: https://lscsoft.docs.ligo.org/lalsuite/lal/

.. |lal.LIGOTimeGPS| replace:: `lal.LIGOTimeGPS`
.. _lal.LIGOTimeGPS: https://lscsoft.docs.ligo.org/lalsuite/lal/struct_l_i_g_o_time_g_p_s.html

.. |lal.REAL8TimeSeries| replace:: `lal.REAL8TimeSeries`
.. _lal.REAL8TimeSeries: https://lscsoft.docs.ligo.org/lalsuite/lal/struct_r_e_a_l8_time_series.html

.. |lalframe| replace:: `lalframe`
.. _lalframe: https://lscsoft.docs.ligo.org/lalsuite/lalframe/

.. |MySQLdb| replace:: `MySQLdb`
.. _MySQLdb: http://mysql-python.sourceforge.net/

.. |nds2| replace:: ``NDS2``
.. _nds2: https://wiki.ligo.org/Computing/NDSClient

.. |numpydoc| replace:: `numpydoc`
.. _numpydoc: https://numpydoc.readthedocs.io/

.. |python-ligo-lw| replace:: `python-ligo-lw`
.. _python-ligo-lw: https://git.ligo.org/kipp.cannon/python-ligo-lw

.. |pycbc| replace:: PyCBC
.. _pycbc: https://pycbc.org/

.. |sphinx| replace:: `sphinx`
.. _sphinx: http://www.sphinx-doc.org/

.. |sphinx-bootstrap-theme| replace:: `sphinx-bootstrap-theme`
.. _sphinx-bootstrap-theme: http://sphinx-bootstrap-theme.readthedocs.io/

.. |sphinxcontrib-programoutput| replace:: `sphinx-programoutput`
.. _sphinxcontrib-programoutput: https://pythonhosted.org/sphinxcontrib-programoutput/

.. |sphinx-automodapi| replace:: `sphinx-automodapi`
.. _sphinx-automodapi: http://sphinx-automodapi.readthedocs.io/

.. |uproot| replace:: `uproot`
.. _uproot: https://uproot.readthedocs.io/

.. -- Objects -----------------------------------

.. |Table| replace:: :class:`~astropy.table.Table`

.. -- Documents ---------------------------------

.. |GWFSpec| replace:: LIGO-T970130
.. _GWFSpec: https://dcc.ligo.org/LIGO-T970130/public

.. -- Other references --------------------------

.. |GravitySpy| replace:: Gravity Spy
.. _GravitySpy: https://gravityspy.org

.. |GWOSCl| replace:: The Gravitational-Wave Open Science Centre (GWOSC)
.. _GWOSCl: https://gwosc.org/

.. |GWOSC| replace:: GWOSC
.. _GWOSC: https://gwosc.org/

.. |GWOSC_AUX_RELEASE| replace:: Auxiliary Channel Three Hour Release
.. _GWOSC_AUX_RELEASE: https://gwosc.org/auxiliary/GW170814/

.. |LIGO-T050017| replace:: LIGO-T050017
.. _LIGO-T050017: https://dcc.ligo.org/LIGO-T050017/public

.. |OSDF| replace:: OSDF
.. _OSDF: https://osg-htc.org/services/osdf.html

.. |OSDFl| replace:: the Open Science Data Federation (OSDF)
.. _OSDF: https://osg-htc.org/services/osdf.html

.. -- Event science summaries -------------------

.. catalogues

.. |GWTCl| replace:: Gravitational-Wave Transient Catalogue (GWTC)
.. _GWTCl: https://gwosc.org/eventapi/html/GWTC/

.. |GWTC| replace:: GWTC
.. _GWTC: https://gwosc.org/eventapi/html/GWTC/

.. |GWTC-1l| replace:: Gravitational-Wave Transient Catalogue (GWTC) 1
.. _GWTC-1l: https://gwosc.org/GWTC-1/

.. |GWTC-1| replace:: GWTC-1
.. _GWTC-1: https://gwosc.org/GWTC-1/

.. |GWTC-2l| replace:: Gravitational-Wave Transient Catalogue (GWTC) 2
.. _GWTC-2l: https://gwosc.org/GWTC-2/

.. |GWTC-2| replace:: GWTC-2
.. _GWTC-2: https://gwosc.org/GWTC-2/

.. |GWTC-2.1l| replace:: Gravitational-Wave Transient Catalogue (GWTC) 2.1
.. _GWTC-2.1l: https://gwosc.org/GWTC-2.1/

.. |GWTC-2.1| replace:: GWTC-2.1
.. _GWTC-2.1: https://gwosc.org/GWTC-2.1/

.. |GWTC-3l| replace:: Gravitational-Wave Transient Catalogue (GWTC) 3
.. _GWTC-3l: https://gwosc.org/GWTC-3/

.. |GWTC-3| replace:: GWTC-3
.. _GWTC-3: https://gwosc.org/GWTC-3/

.. events

.. |GW150914| replace:: GW150914
.. _GW150914: https://www.ligo.org/science/Publication-GW150914/

.. |GW170814| replace:: GW170814
.. _GW170814: https://www.ligo.org/science/Publication-GW170814/

.. |GW170817| replace:: GW170817
.. _GW170817: https://www.ligo.org/science/Publication-GW170817BNS/

.. |GW200105| replace:: GW200105
.. _GW200105: https://www.ligo.org/science/Publication-NSBHDiscovery/
